==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-integer/xl-react-dip-integer-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {hasValue} from '../../utils/components-utils';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-dip-integer.less';

export class XlReactDipIntegerComponent extends PureComponent {
    static propTypes = {
        assignRef: PropTypes.func,
        description: PropTypes.string,
        disabled: PropTypes.bool,
        handleChange: PropTypes.func,
        handleErase: PropTypes.func,
        label: PropTypes.string,
        message: xlMessageTypeProp,
        model: PropTypes.any,
        onValidityChange: PropTypes.func,
        placeholder: PropTypes.string,
        required: PropTypes.bool,
        valid: PropTypes.bool
    };

    render() {
        const closeField = () => !this.props.disabled && hasValue(this.props.model) ?
            <span className="xl-react-btn-close" onClick={this.props.handleErase}/> : <span/>;

        return <XlReactFormItemControl {...({...this.props, controlClass: 'xl-react-dip-integer'})}>
            <input
                className={classNames(
                    validationMessageClasses(this.props.valid, this.props.message),
                )}
                disabled={this.props.disabled}
                onChange={this.props.handleChange}
                placeholder={this.props.placeholder}
                ref={this.props.assignRef}
                required={this.props.required}
                type="text"
                value={this.props.model}
            />
            {closeField()}
        </XlReactFormItemControl>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/xl-react-dip-integer/xl-react-dip-integer-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {hasValue} from '../../utils/components-utils';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-dip-integer.less';

export class XlReactDipIntegerComponent extends PureComponent {
    static propTypes = {
        assignRef: PropTypes.func,
        description: PropTypes.string,
        disabled: PropTypes.bool,
        handleChange: PropTypes.func,
        handleErase: PropTypes.func,
        label: PropTypes.string,
        message: xlMessageTypeProp,
        model: PropTypes.any,
        onValidityChange: PropTypes.func,
        placeholder: PropTypes.string,
        required: PropTypes.bool,
        valid: PropTypes.bool
    };

    render() {
        const closeField = () => !this.props.disabled && hasValue(this.props.model) ?
            <span className="xl-react-btn-close" onClick={this.props.handleErase}/> : <span/>;

        return <XlReactFormItemControl {...({...this.props, controlClass: 'xl-react-dip-integer'})}>
            <input
                className={classNames(
                    validationMessageClasses(this.props.valid, this.props.message)
                )}
                disabled={this.props.disabled}
                onChange={this.props.handleChange}
                placeholder={this.props.placeholder}
                ref={this.props.assignRef}
                required={this.props.required}
                type="text"
                value={this.props.model}
            />
            {closeField()}
        </XlReactFormItemControl>;
    }
}
